@@ -1,4 +1,6 @@
-package DBIx::Class::Schema::Loader::DBI::Oracle;
+package # hide from pause/cpan for now, as there's a permissions
+        # issue and it's screwing the rest of the package
+  DBIx::Class::Schema::Loader::DBI::Oracle;
 
 use strict;
 use warnings;
@@ -6,7 +8,7 @@ use base 'DBIx::Class::Schema::Loader::DBI';
 use Carp::Clan qw/^DBIx::Class/;
 use Class::C3;
 
-our $VERSION = '0.04001';
+our $VERSION = '0.04002';
 
 =head1 NAME
 
